@@ -29,6 +29,9 @@ Marks
    Scatter
    Hist
    Bars
+   Graph
+   GridHeatMap
+   HeatMap
    Label
    OHLC
    Pie
@@ -438,7 +441,8 @@ class _ScatterBase(Mark):
         'y': {'orientation': 'vertical', 'dimension': 'y'},
         'color': {'dimension': 'color'},
         'size': {'dimension': 'size'},
-        'opacity': {'dimension': 'opacity'}
+        'opacity': {'dimension': 'opacity'},
+        'rotation': {'dimension': 'rotation'}
     }).tag(sync=True)
     default_opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
     hovered_style = Dict().tag(sync=True)
@@ -585,6 +589,16 @@ class Scatter(_ScatterBase):
     colors = List(trait=Color(default_value=None, allow_none=True),
                   default_value=['DeepSkyBlue']).tag(sync=True,
                   display_name='Colors')
+    scales_metadata = Dict({
+        'x': {'orientation': 'horizontal', 'dimension': 'x'},
+        'y': {'orientation': 'vertical', 'dimension': 'y'},
+        'color': {'dimension': 'color'},
+        'size': {'dimension': 'size'},
+        'opacity': {'dimension': 'opacity'},
+        'rotation': {'dimension': 'rotation'},
+        'skew': {'dimension': 'skew'}
+    }).tag(sync=True)
+
     @property
     def default_colors(self):
         return self.colors
@@ -771,6 +785,8 @@ class Boxplot(Mark):
         too short, or the element of the list is set to None.
     outlier-color: color
         color for the outlier
+    box_width: int (default: 30)
+        width of the box in pixels. The minimum value is 5
 
     Data Attributes
 
@@ -800,6 +816,7 @@ class Boxplot(Mark):
     box_fill_color = Color('dodgerblue', sync=True, display_name='Fill color for the box')
     outlier_fill_color = Color('gray').tag(sync=True, display_name='Outlier fill color')
     opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
+    box_width = Int(30, min=5).tag(sync=True, display_name='Box Width')
 
     _view_name = Unicode('Boxplot').tag(sync=True)
     _model_name = Unicode('BoxplotModel').tag(sync=True)
@@ -986,8 +1003,8 @@ class Pie(Mark):
     stroke: color (default: 'white')
         stroke color for the marker
     opacities: list of floats (default: [])
-        Opacities for the slices of the Pie mark. Defaults to 1 when the list is
-        too short, or the element of the list is set to None.
+        Opacities for the slices of the Pie mark. Defaults to 1 when the list
+        is too short, or the element of the list is set to None.
     sort: bool (default: False)
         sort the pie slices by descending sizes
     x: Float (default: 0.5) or Date
@@ -1004,8 +1021,12 @@ class Pie(Mark):
         start angle of the pie (from top), in degrees
     end_angle: Float (default: 360.0)
         end angle of the pie (from top), in degrees
-    display_labels: bool (default: True)
-        display the labels on the pie
+    display_labels: {'none', 'inside', 'outside'} (default: 'inside')
+        label display options
+    display_values: bool (default: False)
+        if True show values along with labels
+    values_format: string (default: '.2f')
+        format for displaying values
     label_color: Color or None (default: None)
         color of the labels
     font_size: string (default: '14px')
@@ -1035,8 +1056,14 @@ class Pie(Mark):
     name = 'Pie chart'
 
     # Scaled attributes
-    sizes = Array([]).tag(sync=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
-    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    sizes = Array([]).tag(sync=True, rtype='Number', **array_serialization)\
+        .valid(array_squeeze, array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True,
+                                             scaled=True,
+                                             rtype='Color',
+                                             atype='bqplot.ColorAxis',
+                                             **array_serialization)\
+        .valid(array_squeeze, array_dimension_bounds(1, 1))
 
     # Other attributes
     x = (Float(0.5) | Date() | Unicode()).tag(sync=True)
@@ -1045,14 +1072,19 @@ class Pie(Mark):
     scales_metadata = Dict({'color': {'dimension': 'color'}}).tag(sync=True)
     sort = Bool().tag(sync=True)
     colors = List(trait=Color(default_value=None, allow_none=True),
-                  default_value=CATEGORY10).tag(sync=True, display_name='Colors')
+                  default_value=CATEGORY10).tag(sync=True,
+                                                display_name='Colors')
     stroke = Color(None, allow_none=True).tag(sync=True)
-    opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
+    opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True))\
+        .tag(sync=True, display_name='Opacities')
     radius = Float(180.0, min=0.0, max=float('inf')).tag(sync=True)
     inner_radius = Float(0.1, min=0.0, max=float('inf')).tag(sync=True)
     start_angle = Float().tag(sync=True)
     end_angle = Float(360.0).tag(sync=True)
-    display_labels = Bool(True).tag(sync=True)
+    display_labels = Enum(['none', 'inside', 'outside'],
+                          default_value='inside').tag(sync=True)
+    display_values = Bool(False).tag(sync=True)
+    values_format = Unicode(default_value='.1f').tag(sync=True)
     label_color = Color(None, allow_none=True).tag(sync=True)
     font_size = Unicode(default_value='10px').tag(sync=True)
     font_weight = Enum(['bold', 'normal', 'bolder'],
@@ -1300,3 +1332,97 @@ class HeatMap(Mark):
 
     _view_name = Unicode('HeatMap').tag(sync=True)
     _model_name = Unicode('HeatMapModel').tag(sync=True)
+
+
+class Graph(Mark):
+    """Graph with nodes and links.
+
+    Attributes
+    ----------
+    node_data: List
+        list of node attributes for the graph
+    link_matrix: numpy.ndarray of shape(len(nodes), len(nodes))
+        link data passed as 2d matrix
+    link_data: List
+        list of link attributes for the graph
+    charge: int (default: -300)
+        charge of force layout. Will be ignored when x and y data attributes
+        are set
+    link_distance: float (default: 100)
+        link distance in pixels between nodes. Will be ignored when x and y
+        data attributes are set
+    link_type: {'arc', 'line', 'slant_line'} (default: 'arc')
+        Enum representing link type
+    directed: bool (default: True)
+        directed or undirected graph
+    highlight_links: bool (default: True)
+        highlights incoming and outgoing links when hovered on a node
+    colors: list (default: CATEGORY10)
+        list of node colors
+
+    Data Attributes
+
+    x: numpy.ndarray (default: [])
+        abscissas of the node data points (1d array)
+    y: numpy.ndarray (default: [])
+        ordinates of the node data points (1d array)
+    color: numpy.ndarray or None (default: None)
+        color of the node data points (1d array).
+    link_color: numpy.ndarray of shape(len(nodes), len(nodes))
+        link data passed as 2d matrix
+    """
+    charge = Int(-600).tag(sync=True)
+    link_distance = Float(100).tag(sync=True)
+    node_data = List().tag(sync=True)
+    link_data = List().tag(sync=True)
+    link_matrix = Array([]).tag(sync=True, rtype='Number',
+                                **array_serialization)\
+        .valid(array_squeeze, array_dimension_bounds(1, 2))
+    link_type = Enum(['arc', 'line', 'slant_line'],
+                     default_value='arc').tag(sync=True)
+    directed = Bool(True).tag(sync=True)
+    colors = List(trait=Color(default_value=None, allow_none=True),
+                  default_value=CATEGORY10).tag(sync=True,
+                                                display_name='Colors')
+    interactions = Dict({'hover': 'tooltip', 'click': 'select'}).tag(sync=True)
+    highlight_links = Bool(True).tag(sync=True)
+
+    # Scaled attributes
+    x = Array([], allow_none=True).tag(sync=True,
+                                       scaled=True,
+                                       rtype='Number',
+                                       atype='bqplot.Axis',
+                                       **array_serialization)\
+        .valid(array_dimension_bounds(1, 1))
+    y = Array([], allow_none=True).tag(sync=True,
+                                       scaled=True,
+                                       rtype='Number',
+                                       atype='bqplot.Axis',
+                                       **array_serialization)\
+        .valid(array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True,
+                                             scaled=True,
+                                             rtype='Color',
+                                             atype='bqplot.ColorAxis',
+                                             **array_serialization)\
+        .valid(array_squeeze, array_dimension_bounds(1, 1))
+
+    link_color = Array([]).tag(sync=True, rtype='Color',
+                               atype='bqplot.ColorAxis',
+                               **array_serialization)\
+        .valid(array_squeeze, array_dimension_bounds(1, 2))
+
+    hovered_style = Dict().tag(sync=True)
+    unhovered_style = Dict().tag(sync=True)
+    hovered_point = Int(None, allow_none=True).tag(sync=True)
+
+    # Other attributes
+    scales_metadata = Dict({
+        'x': {'orientation': 'horizontal', 'dimension': 'x'},
+        'y': {'orientation': 'vertical', 'dimension': 'y'},
+        'color': {'dimension': 'color'},
+        'link_color': {'dimension': 'link_color'}
+    }).tag(sync=True)
+
+    _model_name = Unicode('GraphModel').tag(sync=True)
+    _view_name = Unicode('Graph').tag(sync=True)
