@@ -42,6 +42,10 @@ Pyplot
    xlim
    ylim
 
+   axes
+   xlabel
+   ylabel
+
 """
 import sys
 from collections import OrderedDict
@@ -53,7 +57,7 @@ from .scales import Scale, LinearScale, Mercator
 from .axes import Axis
 from .marks import (
         Lines, Scatter, Hist, Bars, OHLC, Pie, Map,
-        Label, HeatMap, topo_load
+        Label, HeatMap, GridHeatMap, topo_load
     )
 from .toolbar import Toolbar
 from .interacts import (
@@ -61,6 +65,7 @@ from .interacts import (
         IndexSelector, MultiSelector, LassoSelector
     )
 from traitlets.utils.sentinel import Sentinel
+import functools
 
 Keep = Sentinel('Keep', 'bqplot.pyplot', '''
         Used in bqplot.pyplot to specify that the same scale should be used for
@@ -236,6 +241,7 @@ def _process_data(*kwarg_names):
     """Helper function to handle data keyword argument
     """
     def _data_decorator(func):
+        @functools.wraps(func)
         def _mark_with_data(*args, **kwargs):
             data = kwargs.pop('data', None)
             if data is None:
@@ -245,6 +251,12 @@ def _process_data(*kwarg_names):
                 data_kwargs = {
                    kw: data[kwargs[kw]] if hashable(data, kwargs[kw]) else kwargs[kw] for kw in set(kwarg_names).intersection(list(kwargs.keys()))
                 }
+                try:
+                    # if any of the plots want to use the index_data, they can use it by referring to
+                    # this attribute.
+                    data_kwargs['index_data'] = data.index
+                except AttributeError as e:
+                    pass
                 kwargs_update = kwargs.copy()
                 kwargs_update.update(data_kwargs)
                 return func(*data_args, **kwargs_update)
@@ -394,6 +406,50 @@ def axes(mark=None, options={}, **kwargs):
     return axes
 
 
+def _set_label(label, mark, dim, **kwargs):
+    """Helper function to set labels for an axis
+    """
+    if mark is None:
+        mark = _context['last_mark']
+    if mark is None:
+        return {}
+    fig = kwargs.get('figure', current_figure())
+    scales = mark.scales
+    scale_metadata = mark.scales_metadata.get(dim, {})
+    scale = scales.get(dim, None)
+    if scale is None:
+        return
+    dimension = scale_metadata.get('dimension', scales[dim])
+    axis = _fetch_axis(fig, dimension, scales[dim])
+
+    if axis is not None:
+        _apply_properties(axis, {'label': label})
+
+
+def xlabel(label=None, mark=None, **kwargs):
+    """Sets the value of label for an axis whose associated scale has the
+    dimension `x`.
+
+    Parameters
+    ----------
+    label: Unicode or None (default: None)
+        The label for x axis
+    """
+    _set_label(label, mark, 'x', **kwargs)
+
+
+def ylabel(label=None, mark=None, **kwargs):
+    """Sets the value of label for an axis whose associated scale has the
+    dimension `y`.
+
+    Parameters
+    ----------
+    label: Unicode or None (default: None)
+        The label for y axis
+    """
+    _set_label(label, mark, 'y', **kwargs)
+
+
 def grids(fig=None, value='solid'):
     """Sets the value of the grid_lines for the axis to the passed value.
     The default value is `solid`.
@@ -607,10 +663,12 @@ def plot(*args, **kwargs):
         If the value is None, the current figure is used.
     """
     marker_str = None
-
     if len(args) == 1:
         kwargs['y'] = args[0]
-        kwargs['x'] = _infer_x_for_line(args[0])
+        if kwargs.get('index_data', None) is not None:
+            kwargs['x'] = kwargs['index_data']
+        else:
+            kwargs['x'] = _infer_x_for_line(args[0]);
     elif len(args) == 2:
         if type(args[1]) == str:
             kwargs['y'] = args[0]
@@ -645,7 +703,6 @@ def plot(*args, **kwargs):
     else:
         return _draw_mark(Lines, **kwargs)
 
-
 def ohlc(*args, **kwargs):
     """Draw OHLC bars or candle bars in the current context figure.
 
@@ -873,6 +930,27 @@ def heatmap(color, **kwargs):
     kwargs['color'] = color
     return _draw_mark(HeatMap, **kwargs)
 
+
+def gridheatmap(color, **kwargs):
+    """Draw a GridHeatMap in the current context figure.
+
+    Parameters
+    ----------
+    color: numpy.ndarray, 2d
+        Matrix of color of the data points
+    options: dict (default: {})
+        Options for the scales to be created. If a scale labeled 'x' is
+        required for that mark, options['x'] contains optional keyword
+        arguments for the constructor of the corresponding scale type.
+    axes_options: dict (default: {})
+        Options for the axes to be created. If an axis labeled 'x' is required
+        for that mark, axes_options['x'] contains optional keyword arguments
+        for the constructor of the corresponding axis type.
+    """
+    kwargs['color'] = color
+    return _draw_mark(GridHeatMap, **kwargs)
+
+
 def _add_interaction(int_type, **kwargs):
     """Add the interaction for the specified type.
 
